@@ -73,15 +73,10 @@ class Jobs(object):
         environment=dict(type="DEEPLEARNING_PY38"),
         data=dict(),
         model=dict(),
+        endpoint=dict(),
         **kwargs,
     ):
 
-        if type in ["headless", "interactive"]:
-            new_type = "notebook" if type == "interactive" else "training"
-            warnings.warn(
-                f"'{type}' type is deprecated, use '{new_type}' instead.",
-                DeprecationWarning,
-            )
         gpu_types = await self.trainml.gpu_types.list()
 
         selected_gpu_type = next(
@@ -108,6 +103,7 @@ class Jobs(object):
             environment=environment,
             data=data,
             model=model,
+            endpoint=endpoint,
             source_job_uuid=kwargs.get("source_job_uuid"),
         )
         payload = {
@@ -180,11 +176,15 @@ class Job:
     def credits(self) -> float:
         return self._credits
 
+    @property
+    def url(self) -> str:
+        return self._job.get("endpoint").get("url")
+
     @property
     def notebook_url(self) -> str:
         if self.type != "notebook":
             return None
-        return f"https://notebook.{self.trainml.domain_suffix}/{self.id}/?token={self._job.get('nb_token')}"
+        return f"{self.url}/{self.id}/?token={self._job.get('nb_token')}"
 
     def __str__(self):
         return json.dumps(self.dict)
@@ -371,7 +371,7 @@ class Job:
 
     async def copy(self, name, **kwargs):
         logging.debug(f"copy request - name: {name} ; kwargs: {kwargs}")
-        if self.type not in ["interactive", "notebook"]:
+        if self.type != "notebook":
             raise SpecificationError(
                 "job", "Only notebook job types can be copied"
             )
@@ -407,15 +407,13 @@ class Job:
                 "status",
                 f"Invalid wait_for status {status}.  Valid statuses are: {valid_statuses}",
             )
-        if (
-            self.type == "headless" or self.type == "training"
-        ) and status == "stopped":
+        if (self.type == "training") and status == "stopped":
             warnings.warn(
                 "'stopped' status is deprecated for training jobs, use 'finished' instead.",
                 DeprecationWarning,
             )
         if self.status == status or (
-            (self.type == "headless" or self.type == "training")
+            self.type == "training"
             and status == "finished"
             and self.status == "stopped"
         ):
@@ -432,7 +430,7 @@ class Job:
                     return
                 raise e
             if self.status == status or (
-                (self.type == "headless" or self.type == "training")
+                self.type == "training"
                 and status == "finished"
                 and self.status == "stopped"
             ):
